==> mule-metadata-model-xml-1.0.0-sources.jar: org/mule/metadata/xml/api/handler/NumberHandler.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.xml.api.handler;

import static org.mule.apache.xerces.xs.XSSimpleTypeDefinition.FACET_MAXINCLUSIVE;
import static org.mule.apache.xerces.xs.XSSimpleTypeDefinition.FACET_MININCLUSIVE;
import static org.mule.metadata.xml.api.utils.SchemaHelper.getFacet;

import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.NumberTypeBuilder;
import org.mule.metadata.api.builder.TypeBuilder;
import org.mule.metadata.xml.api.utils.SchemaHelper;
import org.mule.metadata.xml.api.utils.XmlConstants;

import java.util.Arrays;
import java.util.Optional;

import javax.xml.namespace.QName;

import org.mule.apache.xerces.impl.dv.xs.XSSimpleTypeDecl;

public class NumberHandler implements XmlHandler {

  public static final java.util.List<QName> NUMBER_TYPES =
      Arrays.asList(XmlConstants.XSD_BYTE, XmlConstants.XSD_INT, XmlConstants.XSD_INTEGER, XmlConstants.XSD_SHORT,
                    XmlConstants.XSD_NEGATIVEINTEGER, XmlConstants.XSD_NONNEGATIVEINTEGER,
                    XmlConstants.XSD_NONPOSITIVEINTEGER, XmlConstants.XSD_POSITIVEINTEGER, XmlConstants.XSD_UNSIGNEDBYTE,
                    XmlConstants.XSD_UNSIGNEDINT, XmlConstants.XSD_UNSIGNEDSHORT, XmlConstants.XSD_LONG,
                    XmlConstants.XSD_UNSIGNEDLONG,
                    XmlConstants.XSD_FLOAT, XmlConstants.XSD_DOUBLE, XmlConstants.XSD_DECIMAL);

  @Override
  public boolean handles(QName schema) {
    return NUMBER_TYPES.contains(schema);
  }

  @Override
  public TypeBuilder<?> handle(XSSimpleTypeDecl element, Optional<String> defaultValue, BaseTypeBuilder builder) {
    final NumberTypeBuilder numberType = builder.numberType();

    if (defaultValue.isPresent() && !defaultValue.get().isEmpty()) {
      numberType.defaultValue(defaultValue.get());
    }

    // Boundary
    final Optional<Number> minLength = Optional.ofNullable(getFacet(element, FACET_MININCLUSIVE))
        .map(SchemaHelper::getDoubleValue);
    final Optional<Number> maxLength = Optional.ofNullable(getFacet(element, FACET_MAXINCLUSIVE))
        .map(SchemaHelper::getDoubleValue);

    if (minLength.isPresent() || maxLength.isPresent()) {
      numberType.range(minLength.orElse(null), maxLength.orElse(null));
    }
    return numberType;
  }
}

==> mule-metadata-model-xml-1.1.1-sources.jar: org/mule/metadata/xml/api/handler/NumberHandler.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.xml.api.handler;

import static org.mule.apache.xerces.xs.XSSimpleTypeDefinition.FACET_MAXINCLUSIVE;
import static org.mule.apache.xerces.xs.XSSimpleTypeDefinition.FACET_MININCLUSIVE;
import static org.mule.metadata.xml.internal.utils.SchemaHelper.getFacet;
import org.mule.apache.xerces.impl.dv.xs.XSSimpleTypeDecl;
import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.NumberTypeBuilder;
import org.mule.metadata.api.builder.TypeBuilder;
import org.mule.metadata.xml.api.utils.XmlConstants;
import org.mule.metadata.xml.internal.utils.SchemaHelper;

import java.util.Arrays;
import java.util.Optional;

import javax.xml.namespace.QName;

public class NumberHandler implements XmlHandler {

  public static final java.util.List<QName> NUMBER_TYPES =
      Arrays.asList(XmlConstants.XSD_BYTE, XmlConstants.XSD_INT, XmlConstants.XSD_INTEGER, XmlConstants.XSD_SHORT,
                    XmlConstants.XSD_NEGATIVEINTEGER, XmlConstants.XSD_NONNEGATIVEINTEGER,
                    XmlConstants.XSD_NONPOSITIVEINTEGER, XmlConstants.XSD_POSITIVEINTEGER, XmlConstants.XSD_UNSIGNEDBYTE,
                    XmlConstants.XSD_UNSIGNEDINT, XmlConstants.XSD_UNSIGNEDSHORT, XmlConstants.XSD_LONG,
                    XmlConstants.XSD_UNSIGNEDLONG,
                    XmlConstants.XSD_FLOAT, XmlConstants.XSD_DOUBLE, XmlConstants.XSD_DECIMAL);

  @Override
  public boolean handles(QName schema) {
    return NUMBER_TYPES.contains(schema);
  }

  @Override
  public TypeBuilder<?> handle(XSSimpleTypeDecl element, Optional<String> defaultValue, BaseTypeBuilder builder) {
    final NumberTypeBuilder numberType = builder.numberType();

    if (defaultValue.isPresent() && !defaultValue.get().isEmpty()) {
      numberType.defaultValue(defaultValue.get());
    }

    // Boundary
    final Optional<Number> minLength = Optional.ofNullable(getFacet(element, FACET_MININCLUSIVE))
        .map(SchemaHelper::getDoubleValue);
    final Optional<Number> maxLength = Optional.ofNullable(getFacet(element, FACET_MAXINCLUSIVE))
        .map(SchemaHelper::getDoubleValue);

    if (minLength.isPresent() || maxLength.isPresent()) {
      numberType.range(minLength.orElse(null), maxLength.orElse(null));
    }
    return numberType;
  }
}
